aboutsummaryrefslogtreecommitdiffstats
path: root/include/items.php
diff options
context:
space:
mode:
authorfriendica <info@friendica.com>2012-05-17 19:59:46 -0700
committerfriendica <info@friendica.com>2012-05-17 19:59:46 -0700
commit7cfa7a7671f0bf8316bc63912452e156fc48129e (patch)
treef688f6a65a3e6fe943e5d69858be650835b2dec3 /include/items.php
parentd5d853f37f5b42d4b78f823ed0fb154064ee0e70 (diff)
downloadvolse-hubzilla-7cfa7a7671f0bf8316bc63912452e156fc48129e.tar.gz
volse-hubzilla-7cfa7a7671f0bf8316bc63912452e156fc48129e.tar.bz2
volse-hubzilla-7cfa7a7671f0bf8316bc63912452e156fc48129e.zip
tell browser not to cache permission denied (private) photos so that after authenticating we don't have to fight the browser - plus more prvgroup work
Diffstat (limited to 'include/items.php')
-rw-r--r--include/items.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/items.php b/include/items.php
index 51e21d289..ac7580cc1 100644
--- a/include/items.php
+++ b/include/items.php
@@ -2199,7 +2199,7 @@ function local_delivery($importer,$data) {
if($is_reply) {
$community = false;
- if($importer['page-flags'] == PAGE_COMMUNITY) {
+ if($importer['page-flags'] == PAGE_COMMUNITY || $importer['page-flags'] == PAGE_PRVGROUP ) {
$sql_extra = '';
$community = true;
logger('local_delivery: possible community reply');
@@ -2226,8 +2226,8 @@ function local_delivery($importer,$data) {
if($r && count($r))
$is_a_remote_comment = true;
// Does this have the characteristics of a community comment?
// If it's a reply to a wall post on a community page it's a
// valid community comment. Also forum_mode makes it valid for sure.
// If neither, it's not.
@@ -2226,8 +2226,8 @@ function local_delivery($importer,$data) {
if($r && count($r))
$is_a_remote_comment = true;
- // Does this have the characteristics of a community comment?
- // If it's a reply to a wall post on a community page it's a
+ // Does this have the characteristics of a community or private group comment?
+ // If it's a reply to a wall post on a community/prvgroup page it's a
// valid community comment. Also forum_mode makes it valid for sure.
// If neither, it's not.